pub enum InviteKeyBundleError {
DecodingFailed,
KeySealingFailed,
KeyUnsealingFailed,
MissingKeyId(String),
}Expand description
Errors that can occur when creating an invite key envelope
Variants
DecodingFailed
Decoding the encrypted InviteKeyEnvelope failed
KeySealingFailed
The key wrapping failed while using the provided organization key
KeyUnsealingFailed
The key unsealing failed while using the provided organization key
MissingKeyId(String)
The key_id was not found in the key context store