pub struct InviteKeyBundle {
raw_key_data: InviteKeyData,
sealed_key_envelope: InviteKeyEnvelope,
}Expand description
A struct for holding the invitation key and the invitation key sealed by the organization key
Fields
raw_key_data: InviteKeyDatasealed_key_envelope: InviteKeyEnvelopeImplementations
Sourceimpl InviteKeyBundle
impl InviteKeyBundle
Sourcepub fn make<Ids: KeySlotIds>(
organization_key: Ids::Symmetric,
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Result<Self, InviteKeyBundleError>
pub fn make<Ids: KeySlotIds>( organization_key: Ids::Symmetric, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<Self, InviteKeyBundleError>
Generates a brand new invitation key and wraps it with the provided organization key.
Sourcepub fn dangerous_get_raw_invite_key(&self) -> &InviteKeyData
pub fn dangerous_get_raw_invite_key(&self) -> &InviteKeyData
Get the raw invite key bytes using InviteKeyData
CRITICAL: this data MUST NOT be sent to the server
This can be base64url encoded for URL use only:
ⓘ
let key: &InviteKeyData = bundle.dangerous_get_raw_invite_key();
let key_bytes: String = String::from(key);Sourcepub fn get_sealed_invite_key_envelope(&self) -> &InviteKeyEnvelope
pub fn get_sealed_invite_key_envelope(&self) -> &InviteKeyEnvelope
Gets the sealed invite key (wrapped using the organization key)