pub struct InviteKeyEnvelope(EncString);Expand description
Struct for holding the wrapped invite key data. Currently supports encstring but the inner type must remain private as it may be extended in the future.
Tuple Fields
0: EncStringImplementations
Sourceimpl InviteKeyEnvelope
impl InviteKeyEnvelope
Sourcepub fn unseal<Ids: KeySlotIds>(
&self,
organization_key: Ids::Symmetric,
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Result<InviteKeyData, InviteKeyBundleError>
pub fn unseal<Ids: KeySlotIds>( &self, organization_key: Ids::Symmetric, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<InviteKeyData, InviteKeyBundleError>
Given a correct organization key, unseals the InviteKeyEnvelope,
returning the InviteKeyData sealed inside.